==> dnet-patcheditor-ui-1.0.0-20190128.135938-8-sources.jar: eu/dnetlib/functionality/modular/ui/patcheditor/record/model/Record.java <==
package eu.dnetlib.functionality.modular.ui.patcheditor.record.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

public class Record implements Serializable {

	/**
	 *
	 */
	private static final long serialVersionUID = 1814327287971524885L;

	final List<Title> titles = new ArrayList<Title>();
	final List<Description> descriptions = new ArrayList<Description>();
	final List<Language> languages = new ArrayList<Language>();
	final List<Keyword> keywords = new ArrayList<Keyword>();
	final List<CollectionData> collections = new ArrayList<CollectionData>();

	Color colour = new Color();
	Sound sound = new Sound();
	Right rights = new Right();
	DigitalObject digitalObject = new DigitalObject();

	String repositoryId;
	String entityType;
	String gauge;
	String countryOfReference;
	String productionYear;
	String duration;
	String provenance;

	public Color getColour() {
		return colour;
	}

	public void setColour(Color colour) {
		this.colour = colour;
	}

	public Sound getSound() {
		return sound;
	}

	public void setSound(Sound sound) {
		this.sound = sound;
	}

	public Right getRights() {
		return rights;
	}

	public void setRights(Right rights) {
		this.rights = rights;
	}

	public String getRepositoryId() {
		return repositoryId;
	}

	public void setRepositoryId(String repositoryId) {
		this.repositoryId = repositoryId;
	}

	public String getEntityType() {
		return entityType;
	}

	public void setEntityType(String entityType) {
		this.entityType = entityType;
	}

	public String getGauge() {
		return gauge;
	}

	public void setGauge(String gauge) {
		this.gauge = gauge;
	}

	public String getCountryOfReference() {
		return countryOfReference;
	}

	public void setCountryOfReference(String countryOfReference) {
		this.countryOfReference = countryOfReference;
	}

	public String getProductionYear() {
		return productionYear;
	}

	public void setProductionYear(String productionYear) {
		this.productionYear = productionYear;
	}

	public void setDigitalObject(DigitalObject digitalObject) {
		this.digitalObject = digitalObject;
	}

	public String getDuration() {
		return duration;
	}

	public void setDuration(String duration) {
		this.duration = duration;
	}

	public String getProvenance() {
		return provenance;
	}

	public void setProvenance(String provenance) {
		this.provenance = provenance;
	}

	public List<Title> getTitles() {
		return titles;
	}

	public List<Description> getDescriptions() {
		return descriptions;
	}

	public List<Language> getLanguages() {
		return languages;
	}

	public DigitalObject getDigitalObject() {
		return digitalObject;
	}

	public List<Keyword> getKeywords() {
		return keywords;
	}

	public List<CollectionData> getCollections() {
		return collections;
	}

}

==> dnet-patcheditor-ui-1.0.1-20240916.104239-17-sources.jar: eu/dnetlib/functionality/modular/ui/patcheditor/record/model/Record.java <==
package eu.dnetlib.functionality.modular.ui.patcheditor.record.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

public class Record implements Serializable {

	/**
	 *
	 */
	private static final long serialVersionUID = 1814327287971524885L;

	final List<Title> titles = new ArrayList<Title>();
	final List<Description> descriptions = new ArrayList<Description>();
	final List<Language> languages = new ArrayList<Language>();
	final List<Keyword> keywords = new ArrayList<Keyword>();
	final List<CollectionData> collections = new ArrayList<CollectionData>();

	Color colour = new Color();
	Sound sound = new Sound();
	Right rights = new Right();
	DigitalObject digitalObject = new DigitalObject();

	String repositoryId;
	String entityType;
	String gauge;
	String countryOfReference;
	String productionYear;
	String duration;
	String provenance;
	String specificType;

	public Color getColour() {
		return colour;
	}

	public void setColour(Color colour) {
		this.colour = colour;
	}

	public Sound getSound() {
		return sound;
	}

	public void setSound(Sound sound) {
		this.sound = sound;
	}

	public Right getRights() {
		return rights;
	}

	public void setRights(Right rights) {
		this.rights = rights;
	}

	public String getRepositoryId() {
		return repositoryId;
	}

	public void setRepositoryId(String repositoryId) {
		this.repositoryId = repositoryId;
	}

	public String getEntityType() {
		return entityType;
	}

	public void setEntityType(String entityType) {
		this.entityType = entityType;
	}

	public String getGauge() {
		return gauge;
	}

	public void setGauge(String gauge) {
		this.gauge = gauge;
	}

	public String getCountryOfReference() {
		return countryOfReference;
	}

	public void setCountryOfReference(String countryOfReference) {
		this.countryOfReference = countryOfReference;
	}

	public String getProductionYear() {
		return productionYear;
	}

	public void setProductionYear(String productionYear) {
		this.productionYear = productionYear;
	}

	public void setDigitalObject(DigitalObject digitalObject) {
		this.digitalObject = digitalObject;
	}

	public String getDuration() {
		return duration;
	}

	public void setDuration(String duration) {
		this.duration = duration;
	}

	public String getProvenance() {
		return provenance;
	}

	public void setProvenance(String provenance) {
		this.provenance = provenance;
	}

	public List<Title> getTitles() {
		return titles;
	}

	public List<Description> getDescriptions() {
		return descriptions;
	}

	public List<Language> getLanguages() {
		return languages;
	}

	public DigitalObject getDigitalObject() {
		return digitalObject;
	}

	public List<Keyword> getKeywords() {
		return keywords;
	}

	public List<CollectionData> getCollections() {
		return collections;
	}

	public String getSpecificType() {
		return specificType;
	}

	public void setSpecificType(String specificType) {
		this.specificType = specificType;
	}

}
